# mypy-boto3-xray

[![PyPI - mypy-boto3-xray](https://img.shields.io/pypi/v/mypy-boto3-xray.svg?color=blue)](https://pypi.org/project/mypy-boto3-xray)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-xray.svg?color=blue)](https://pypi.org/project/mypy-boto3-xray)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

Type annotations for
[boto3.XRay 1.15.3](https://boto3.amazonaws.com/v1/documentation/api/1.15.3/reference/services/xray.html#XRay) service
compatible with
[VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright)
and other tools.

Generated by [mypy-boto3-buider 3.1.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

- [mypy-boto3-xray](#mypy-boto3-xray)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Service Resource annotations](#service-resource-annotations)
    - [Other resources annotations](#other-resources-annotations)
    - [Collections annotations](#collections-annotations)
    - [Typed dictionations](#typed-dictionations)

## How to install

Install `boto3-stubs` for `XRay` service.

```bash
python -m pip install boto3-stubs[xray]
```

## Usage

### VSCode

- Install [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[xray]` in your environment: `python -m pip install 'boto3-stubs[xray]'`

Both type checking and auto-complete should work for `XRay` service.
No explicit type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[xray]` in your environment: `python -m pip install 'boto3-stubs[xray]'`

Both type checking and auto-complete should work for `XRay` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed `boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[xray]` in your environment: `python -m pip install 'boto3-stubs[xray]'`
- Run `mypy` as usual

Type checking should work for `XRay` service.
No explicit type annotations required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[xray]` in your environment: `python -m pip install 'boto3-stubs[xray]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `XRay` service.
No explicit type annotations required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`XRayClient` provides annotations for `boto3.client("xray")`.

```python
import boto3

from mypy_boto3_xray import XRayClient

client: XRayClient = boto3.client("xray")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: XRayClient = session.client("xray")
```

### Paginators annotations

`mypy_boto3_xray.paginator` module contains type annotations for all paginators.

```python
from mypy_boto3_xray import XRayClient
from mypy_boto3_xray.paginator import (
    BatchGetTracesPaginator,
    GetGroupsPaginator,
    GetSamplingRulesPaginator,
    GetSamplingStatisticSummariesPaginator,
    GetServiceGraphPaginator,
    GetTimeSeriesServiceStatisticsPaginator,
    GetTraceGraphPaginator,
    GetTraceSummariesPaginator,
)

client: XRayClient = boto3.client("xray")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
batch_get_traces_paginator: BatchGetTracesPaginator = client.get_paginator("batch_get_traces")
get_groups_paginator: GetGroupsPaginator = client.get_paginator("get_groups")
get_sampling_rules_paginator: GetSamplingRulesPaginator = client.get_paginator("get_sampling_rules")
get_sampling_statistic_summaries_paginator: GetSamplingStatisticSummariesPaginator = client.get_paginator("get_sampling_statistic_summaries")
get_service_graph_paginator: GetServiceGraphPaginator = client.get_paginator("get_service_graph")
get_time_series_service_statistics_paginator: GetTimeSeriesServiceStatisticsPaginator = client.get_paginator("get_time_series_service_statistics")
get_trace_graph_paginator: GetTraceGraphPaginator = client.get_paginator("get_trace_graph")
get_trace_summaries_paginator: GetTraceSummariesPaginator = client.get_paginator("get_trace_summaries")
```







### Typed dictionations

`mypy_boto3_xray.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_xray.type_defs import (
    AliasTypeDef,
    AnnotationValueTypeDef,
    AvailabilityZoneDetailTypeDef,
    BackendConnectionErrorsTypeDef,
    BatchGetTracesResultTypeDef,
    CreateGroupResultTypeDef,
    CreateSamplingRuleResultTypeDef,
    DeleteSamplingRuleResultTypeDef,
    EdgeStatisticsTypeDef,
    EdgeTypeDef,
    EncryptionConfigTypeDef,
    ErrorRootCauseEntityTypeDef,
    ErrorRootCauseServiceTypeDef,
    ErrorRootCauseTypeDef,
    ErrorStatisticsTypeDef,
    FaultRootCauseEntityTypeDef,
    FaultRootCauseServiceTypeDef,
    FaultRootCauseTypeDef,
    FaultStatisticsTypeDef,
    GetEncryptionConfigResultTypeDef,
    GetGroupResultTypeDef,
    GetGroupsResultTypeDef,
    GetSamplingRulesResultTypeDef,
    GetSamplingStatisticSummariesResultTypeDef,
    GetSamplingTargetsResultTypeDef,
    GetServiceGraphResultTypeDef,
    GetTimeSeriesServiceStatisticsResultTypeDef,
    GetTraceGraphResultTypeDef,
    GetTraceSummariesResultTypeDef,
    GroupSummaryTypeDef,
    GroupTypeDef,
    HistogramEntryTypeDef,
    HttpTypeDef,
    InsightsConfigurationTypeDef,
    InstanceIdDetailTypeDef,
    ListTagsForResourceResponseTypeDef,
    PaginatorConfigTypeDef,
    PutEncryptionConfigResultTypeDef,
    PutTraceSegmentsResultTypeDef,
    ResourceARNDetailTypeDef,
    ResponseTimeRootCauseEntityTypeDef,
    ResponseTimeRootCauseServiceTypeDef,
    ResponseTimeRootCauseTypeDef,
    RootCauseExceptionTypeDef,
    SamplingRuleRecordTypeDef,
    SamplingRuleTypeDef,
    SamplingRuleUpdateTypeDef,
    SamplingStatisticsDocumentTypeDef,
    SamplingStatisticSummaryTypeDef,
    SamplingStrategyTypeDef,
    SamplingTargetDocumentTypeDef,
    SegmentTypeDef,
    ServiceIdTypeDef,
    ServiceStatisticsTypeDef,
    ServiceTypeDef,
    TagTypeDef,
    TelemetryRecordTypeDef,
    TimeSeriesServiceStatisticsTypeDef,
    TraceSummaryTypeDef,
    TraceTypeDef,
    TraceUserTypeDef,
    UnprocessedStatisticsTypeDef,
    UnprocessedTraceSegmentTypeDef,
    UpdateGroupResultTypeDef,
    UpdateSamplingRuleResultTypeDef,
    ValueWithServiceIdsTypeDef,
)

def get_structure() -> AliasTypeDef:
    return {
      ...
    }
```
